==> fetch-s-0.0.2.tgz: package/test/karma.conf.js <==
// Karma configuration
// Generated on Fri Mar 30 2018 14:29:01 GMT+0800 (CST)

module.exports = function(config) {
	config.set({
		// base path that will be used to resolve all patterns (eg. files, exclude)
		basePath: '',

		// frameworks to use
		// available frameworks: https://npmjs.org/browse/keyword/karma-adapter
		frameworks: ['jasmine'],

		// list of files / patterns to load in the browser
		files: ['../test/**/*.spec.js'],

		// list of files / patterns to exclude
		exclude: [],

		// preprocess matching files before serving them to the browser
		// available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
		preprocessors: {
			'../test/**/*.spec.js': ['webpack'],
			'../src/**/*.js': ['coverage']
		},
		coverageReporter: {
			type: 'lcov',
			dir: '../coverage/',
			subdir: '.'
		},
		// test results reporter to use
		// possible values: 'dots', 'progress'
		// available reporters: https://npmjs.org/browse/keyword/karma-reporter
		reporters: ['progress', 'coverage'],

		// web server port
		port: 9876,

		// enable / disable colors in the output (reporters and logs)
		colors: true,

		// level of logging
		// possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
		logLevel: config.LOG_INFO,

		// enable / disable watching file and executing tests whenever any file changes
		autoWatch: true,

		// start these browsers
		// available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
		browsers: ['ChromeHeadless'],

		// Continuous Integration mode
		// if true, Karma captures browsers, runs the tests and exits
		singleRun: true, //（change）

		// Concurrency level
		// how many browser should be started simultaneous
		concurrency: Infinity,
		webpack: {
			module: {
				loaders: [
					{
						test: /\.js$/,
						loader: 'babel-loader',
						exclude: /(node_modules)/
					}
				]
			}
		}
	});
};

==> fetch-s-1.3.1.tgz: package/test/karma.conf.js <==
// Karma configuration
// Generated on Fri Mar 30 2018 14:29:01 GMT+0800 (CST)

module.exports = function(config) {
	config.set({
		// base path that will be used to resolve all patterns (eg. files, exclude)
		basePath: '',

		// frameworks to use
		// available frameworks: https://npmjs.org/browse/keyword/karma-adapter
		frameworks: ['jasmine'],

		// list of files / patterns to load in the browser
		files: ['../test/**/*.spec.js'],

		// list of files / patterns to exclude
		exclude: [],

		// preprocess matching files before serving them to the browser
		// available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
		preprocessors: {
			'../test/**/*.spec.js': ['webpack'],
			'../src/**/*.js': ['coverage']
		},
		coverageReporter: {
			type: 'lcov',
			dir: '../coverage/',
			subdir: '.'
		},
		// test results reporter to use
		// possible values: 'dots', 'progress'
		// available reporters: https://npmjs.org/browse/keyword/karma-reporter
		reporters: ['progress', 'coverage'],

		// web server port
		port: 9876,

		// enable / disable colors in the output (reporters and logs)
		colors: true,

		// level of logging
		// possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
		logLevel: config.LOG_INFO,

		// enable / disable watching file and executing tests whenever any file changes
		autoWatch: true,

		// start these browsers
		// available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
		browsers: ['ChromeHeadless'],

		// Continuous Integration mode
		// if true, Karma captures browsers, runs the tests and exits
		singleRun: true, //（change）

		// Concurrency level
		// how many browser should be started simultaneous
		concurrency: Infinity,
		webpack: {
			module: {
				loaders: [
					{
						test: /\.js$/,
						loader: 'babel-loader',
						exclude: /(node_modules)/,
						query: {
							presets: ['env'],
							plugins: ['istanbul']
						  }
					}
				]
			}
		}
	});
};
